@@ -6,7 +6,7 @@ $block_name = _("Calendar Summary");
  * Horde_Block_Kronolith_summary:: Implementation of the Horde_Block API to
  * display a summary of calendar items.
  *
- * $Horde: kronolith/lib/Block/summary.php,v 1.41.2.3 2005/05/16 23:10:42 jan Exp $
+ * $Horde: kronolith/lib/Block/summary.php,v 1.41.2.7 2007/01/18 15:54:20 jan Exp $
  *
  * @package Horde_Block
  */
@@ -38,8 +38,7 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
     function _title()
     {
         global $registry;
-
-        return Horde::link(Horde::url($registry->getInitialPage(), true), $registry->get('name')) . $registry->get('name') . '</a> :: ' . Horde::link(Horde::applicationUrl('addevent.php', true), _("New Event")) . Horde::img('new.png', _("New Event"), '', Horde::url($registry->getImageDir(), true, -1)) . ' ' . _("New Event") . '</a>';
+        return Horde::link(Horde::url($registry->getInitialPage(), true)) . $registry->get('name') . '</a> <small>' . Horde::link(Horde::applicationUrl('addevent.php', true)) . Horde::img('new.png', _("New Event")) . ' ' . _("New Event") . '</a></small>';
     }
 
     /**
@@ -58,8 +57,6 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
 
         $now = time();
         $today = date('j');
-        $cManager = &new Prefs_CategoryManager();
-        $colors = $cManager->colors();
 
         $startDate = &new Horde_Date(array('year' => date('Y'),
                                            'month' => date('n'),
@@ -83,7 +80,7 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
         $html = '';
         $iMax = $today + $prefs->getValue('summary_days');
         $firstday = true;
-        for ($i = $today; $i < $today + $iMax; $i++) {
+        for ($i = $today; $i < $iMax; ++$i) {
             $day = &new Kronolith_Day(date('n'), $i);
             if (empty($allevents[$day->getStamp()])) {
                 continue;
@@ -91,7 +88,6 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
 
             $events = &$allevents[$day->getStamp()];
             $firstevent = true;
-            $htmldays = array();
 
             $today12am = mktime(0, 0, 0,
                                 $day->month,
@@ -126,7 +122,7 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
                     if (!$firstday) {
                         $html .= '<tr><td colspan="3" style="font-size:2px;">&nbsp;</td></tr>';
                     }
-                    $html .= '<tr><td colspan="3" class="control"><b>';
+                    $html .= '<tr><td colspan="3" class="control"><strong>';
                     if ($day->isToday()) {
                         $dayname = _("Today");
                     } elseif ($day->isTomorrow()) {
@@ -143,14 +139,14 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
                                                   $day->getStamp());
                     $html .= Horde::link($daylink, sprintf(_("Goto %s"),
                                                            $dayname));
-                    $html .= $dayname . '</a></b></td></tr>';
+                    $html .= $dayname . '</a></strong></td></tr>';
                     $firstevent = false;
                     $firstday = false;
                 }
-                $htmlday = '<tr><td class="text" nowrap="nowrap" valign="top">';
+                $html .= '<tr><td class="text" nowrap="nowrap" valign="top">';
                 if ($event->start->timestamp() < $now &&
                     $event->end->timestamp() > $now) {
-                    $htmlday .= '<b>';
+                    $html .= '<strong>';
                 }
 
                 if ($event->start->hour != 0 ||
@@ -158,11 +154,11 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
                     (($event->end->timestamp() - $event->start->timestamp()) %
                      (24 * 60 * 60)) != 0) {
                     if ($prefs->getValue('twentyFour')) {
-                        $time  = date('G:i', $event->start->timestamp()) . '-';
-                        $time .= date('G:i', $event->end->timestamp());
+                        $time = date('G:i', $event->start->timestamp()) . '-' .
+                            date('G:i', $event->end->timestamp());
                     } else {
-                        $time  = date('g:i A', $event->start->timestamp()) . '-';
-                        $time .= date('g:i A', $event->end->timestamp());
+                        $time = date('g:i A', $event->start->timestamp()) . '-' .
+                            date('g:i A', $event->end->timestamp());
                     }
                 } else {
                     $time = _("All day event");
@@ -172,41 +168,33 @@ class Horde_Block_Kronolith_summary extends Horde_Block {
                 if ($location = $event->getLocation()) {
                     $text .= ' (' . $location . ')';
                 }
-                $htmlday .= $time;
+                $html .= $time;
                 if ($event->start->timestamp() < $now &&
                     $event->end->timestamp() > $now) {
-                    $htmlday .= '</b>';
+                    $html .= '</strong>';
                 }
 
-                $categoryColor = isset($colors[$event->getCategory()])
-                    ? $colors[$event->getCategory()]
-                    : $colors['_default_'];
-                $htmlday .= '</td><td class="text">&nbsp;&nbsp;&nbsp;</td>' .
-                    '<td class="block-eventbox" style="background-color: ' .
-                    $categoryColor . '; ' . 'border-color: ' .
-                    Kronolith::borderColor($categoryColor) . ';" valign="top">';
+                $html .= '</td><td class="text">&nbsp;&nbsp;&nbsp;</td>' .
+                    '<td class="block-eventbox category' . md5($event->getCategory()) . '" valign="top">';
 
                 if ($event->start->timestamp() < $now &&
                     $event->end->timestamp() > $now) {
-                    $htmlday .= '<b>';
+                    $html .= '<strong>';
                 }
-                $htmlday .= $event->getLink(null, true);
+                $html .= $event->getLink(null, true);
                 if ($event->start->timestamp() < $now &&
                     $event->end->timestamp() > $now) {
-                    $html .= '</b>';
+                    $html .= '</strong>';
                 }
-                $htmlday .= '</td></tr>';
-                $htmldays[] = $htmlday;
+                $html .= '</td></tr>';
             }
-
-            $html .= implode("\n", $htmldays);
         }
 
         if (empty($html)) {
             return '<em>' . _("No events to display") . '</em>';
         }
 
-        return '<table cellspacing="0" width="100%">' . $html . '</table>';
+        return '<link href="' . Horde::applicationUrl('themes/categoryCSS.php') . '" rel="stylesheet" type="text/css" /><table cellspacing="0" width="100%">' . $html . '</table>';
     }
 
 }
