@@ -4,7 +4,7 @@
  *
  * Act on alarms in events and send emails/pages/etc. to users.
  *
- * $Horde: kronolith/lib/Scheduler/kronolith.php,v 1.25.6.6.2.1 2005/10/27 08:37:03 jan Exp $
+ * $Horde: kronolith/lib/Scheduler/kronolith.php,v 1.25.6.14 2006/12/05 22:30:19 chuck Exp $
  *
  * @package Horde_Scheduler
  */
@@ -25,14 +25,6 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
      */
     var $_calendars = array();
 
-    /**
-     * Cache email address so that we don't spend too much time looking them up
-     * always. Maybe have to expire this at some point?
-     *
-     * @var array
-     */
-    var $_emails = array();
-
     /**
      * The last timestamp that we ran.
      *
@@ -83,10 +75,28 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
             $kronolith->open($calId);
             foreach ($calarms as $eventId) {
                 $event = &$kronolith->getEvent($eventId);
+                if (is_a($event, 'PEAR_Error')) {
+                    continue;
+                }
+
+                if ($event->getRecurType() != KRONOLITH_RECUR_NONE) {
+                    /* Set the event's start date to the next
+                     * recurrence date. This should avoid problems
+                     * when an alarm triggers on a different day from
+                     * the actual event, and make $seenid unique for
+                     * each occurrence of a recurring event. */
+                    $event->start = $event->nextRecurrence($this->_runtime);
+
+                    /* Check for exceptions; do nothing if one is found. */
+                    if ($event->hasException($event->start->year, $event->start->month, $event->start->mday)) {
+                        continue;
+                    }
+                }
+
                 $seenid = $eventId . $event->start->timestamp() . $event->getAlarm();
                 if (!isset($this->_seen[$seenid])) {
                     $this->_seen[$seenid] = true;
-                    $result = $this->remind($calId, $eventId);
+                    $result = $this->remind($calId, $event);
                     if (is_a($result, 'PEAR_Error')) {
                         Horde::logMessage($result, __FILE__, __LINE__, PEAR_LOG_ERR);
                     }
@@ -95,19 +105,13 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
         }
     }
 
-    function remind($calId, $eventId)
+    function remind($calId, &$event)
     {
         global $kronolith, $conf, $shares;
 
         if ($kronolith->getCalendar() != $calId) {
             $kronolith->open($calId);
         }
-        $event = &$kronolith->getEvent($eventId);
-
-        /* Check for exceptions; do nothing if one is found. */
-        if ($event->hasException(date('Y'), date('n'), date('j'))) {
-            return;
-        }
 
         require_once 'Horde/Group.php';
         require_once 'Horde/Identity.php';
@@ -126,49 +130,59 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
         }
 
         $recipients = array();
+        $emails = array();
 
         $users = $share->listUsers(PERMS_READ);
         foreach ($users as $user) {
-            if (empty($this->_emails[$user])) {
-                $identity = &Identity::factory('none', $user);
+            if (empty($emails[$user])) {
+                $identity = &Identity::singleton('none', $user);
                 $email = $identity->getValue('from_addr');
                 if (strstr($email, '@')) {
                     list($mailbox, $host) = explode('@', $email);
-                    $this->_emails[$user] = MIME::rfc822WriteAddress($mailbox, $host, $identity->getValue('fullname'));
+                    $emails[$user] = MIME::rfc822WriteAddress($mailbox, $host, $identity->getValue('fullname'));
                 }
             }
 
-            if (!empty($this->_emails[$user])) {
-                $prefs = &Prefs::singleton($conf['prefs']['driver'], 'horde', $user);
+            if (!empty($emails[$user])) {
+                $prefs = &Prefs::singleton($conf['prefs']['driver'],
+                                           'kronolith', $user);
                 $prefs->retrieve();
-                $lang = $prefs->getValue('language');
-                $twentyFour = $prefs->getValue('twentyFour');
-                if (!isset($recipients[$lang][$twentyFour])) {
-                    $recipients[$lang][$twentyFour] = array();
+                $shown_calendars = unserialize($prefs->getValue('display_cals'));
+                $reminder = $prefs->getValue('event_reminder');
+                if (($reminder == 'owner' && $user == $share->get('owner')) ||
+                    ($reminder == 'show' && in_array($calId, $shown_calendars)) ||
+                    $reminder == 'read') {
+                    $lang = $prefs->getValue('language');
+                    $twentyFour = $prefs->getValue('twentyFour');
+                    $dateFormat = $prefs->getValue('date_format');
+                    if (!isset($recipients[$lang][$twentyFour][$dateFormat])) {
+                        $recipients[$lang][$twentyFour][$dateFormat] = array();
+                    }
+                    $recipients[$lang][$twentyFour][$dateFormat][] = $emails[$user];
                 }
-                $recipients[$lang][$twentyFour][] = $this->_emails[$user];
             }
         }
 
         $groups = $share->listGroups(PERMS_READ);
         $groupManager = &Group::singleton();
         foreach ($groups as $gid) {
-            if (empty($this->_emails[$gid])) {
+            if (empty($emails[$gid])) {
                 $group = $groupManager->getGroupById($gid);
                 if ($email = $group->get('email')) {
-                    $this->_emails[$gid] = $group->get('email');
+                    $emails[$gid] = $group->get('email');
                 }
             }
 
-            if (!empty($this->_emails[$gid])) {
+            if (!empty($emails[$gid])) {
                 $prefs = &Prefs::singleton($conf['prefs']['driver'], 'horde', $gid);
                 $prefs->retrieve();
                 $lang = $prefs->getValue('language');
                 $twentyFour = $prefs->getValue('twentyFour');
-                if (!isset($recipients[$lang][$twentyFour])) {
-                    $recipients[$lang][$twentyFour] = array();
+                $dateFormat = $prefs->getValue('date_format');
+                if (!isset($recipients[$lang][$twentyFour][$dateFormat])) {
+                    $recipients[$lang][$twentyFour][$dateFormat] = array();
                 }
-                $recipients[$lang][$twentyFour][] = $this->_emails[$gid];
+                $recipients[$lang][$twentyFour][$dateFormat][] = $emails[$gid];
             }
         }
 
@@ -177,7 +191,7 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
             return false;
         }
 
-        $msg_headers = &new MIME_Headers();
+        $msg_headers = new MIME_Headers();
         $msg_headers->addMessageIdHeader();
         $msg_headers->addAgentHeader();
         $msg_headers->addHeader('Date', date('r'));
@@ -188,28 +202,33 @@ class Horde_Scheduler_kronolith extends Horde_Scheduler {
         $mail_params = $conf['mailer']['params'];
         if ($mail_driver == 'smtp' && $mail_params['auth'] &&
             empty($mail_params['username'])) {
-            $mail_params['username'] = Auth::getAuth();
-            $mail_params['password'] = Auth::getCredential('password');
+            Horde::logMessage('Reminders don\'t work with user based SMTP authentication.', __FILE__, __LINE__, PEAR_LOG_ERR);
+            return;
         }
 
-        foreach ($recipients as $lang => $lang_recipients) {
+        foreach ($recipients as $lang => $twentyFour) {
             NLS::setLang($lang);
+            NLS::setTextdomain('kronolith', KRONOLITH_BASE . '/locale', NLS::getCharset());
+            String::setDefaultCharset(NLS::getCharset());
+
             $msg_headers->removeHeader('Subject');
             $msg_headers->addHeader('Subject', sprintf(_("Reminder: %s"), $event->title));
 
-            foreach ($lang_recipients as $twentyFour => $tf_recipients) {
-                $message = "\n" . sprintf(_("You requested to be reminded about %s, which is on %s at %s."), $event->title, strftime('%x', $event->start->timestamp()), date($twentyFour ? 'H:i' : 'h:ia', $event->start->timestamp())) . "\n\n" . $event->getDescription();
+            foreach ($twentyFour as $tf => $dateFormat) {
+                foreach ($dateFormat as $df => $df_recipients) {
+                    $message = "\n" . sprintf(_("You requested to be reminded about %s, which is on %s at %s."), $event->title, strftime($df, $event->start->timestamp()), date($tf ? 'H:i' : 'h:ia', $event->start->timestamp())) . "\n\n" . $event->getDescription();
 
-                $mime = &new MIME_Message();
-                $body = &new MIME_Part('text/plain', String::wrap($message, 76, "\n"), NLS::getCharset());
+                    $mime = new MIME_Message();
+                    $body = new MIME_Part('text/plain', String::wrap($message, 76, "\n"), NLS::getCharset());
 
-                $mime->addPart($body);
-                $msg_headers->addMIMEHeaders($mime);
+                    $mime->addPart($body);
+                    $msg_headers->addMIMEHeaders($mime);
 
-                Horde::logMessage(sprintf('Sending reminder for %s to %s', $event->title, implode(', ', $tf_recipients)), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-                $sent = $mime->send(implode(', ', $tf_recipients), $msg_headers, $mail_driver, $mail_params);
-                if (is_a($sent, 'PEAR_Error')) {
-                    return $sent;
+                    Horde::logMessage(sprintf('Sending reminder for %s to %s', $event->title, implode(', ', $df_recipients)), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+                    $sent = $mime->send(implode(', ', $df_recipients), $msg_headers, $mail_driver, $mail_params);
+                    if (is_a($sent, 'PEAR_Error')) {
+                        return $sent;
+                    }
                 }
             }
         }
